AGW Logo

svn SVN Revision 69824 For ultimatelistctrl

This file contains the SVN revision history for ultimatelistctrl, at revision 69824.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 19-Nov-2009 10:19:40 UTC
  • Committer: AG
  • File Size: 457466 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

UltimateListCtrl: fixed issues with int/long types passed to CreateListItem.


svn_diff Diff To Previous Version (69627)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2011/11/01 19:42:21     69627
+++ wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2011/11/27 12:17:50     69824
@@ -3,7 +3,7 @@
# Inspired by and heavily based on the wxWidgets C++ generic version of wxListCtrl.
#
# Andrea Gavana, @ 08 May 2009
# Latest Revision: 31 Oct 2011, 21.00 GMT
#
#
# TODO List
@@ -225,7 +225,7 @@

UltimateListCtrl is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 31 Oct 2011, 21.00 GMT
+Latest Revision: Andrea Gavana @ 27 Nov 2011, 13.00 GMT

Version 0.8

@@ -550,6 +550,10 @@
IL_FIXED_SIZE = 0
IL_VARIABLE_SIZE = 1

+# Python integers, to make long types to work with CreateListItem
+INTEGER_TYPES = [types.IntType, types.LongType]
+
+
# ----------------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------------
@@ -593,7 +597,7 @@
:param `col`: the item column.
"""

-    if type(itemOrId) == types.IntType:
+    if type(itemOrId) in INTEGER_TYPES:
item = UltimateListItem()
item._itemId = itemOrId
item._col = col
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 08 May 2009
-# Latest Revision: 31 Oct 2011, 21.00 GMT
+# Latest Revision: 27 Nov 2011, 13.00 GMT
#
#
Tree